@@ -616,7 +616,7 @@ func (r *ReconcileVirtualMachineImport) importDisks(provider provider.Provider,
 		if err != nil && k8serrors.IsNotFound(err) {
 			// We have to validate the disk status, so we are sure, the disk wasn't manipulated,
 			// before we execute the import:
-			valid, err := provider.ValidateDiskStatus(dv.Name)
+			valid, err := provider.ValidateDiskStatus(dv)
 			if err != nil {
 				return false, err
 			}
@@ -1039,7 +1039,7 @@ func shouldReconcile(instance *v2vv1.VirtualMachineImport) bool {
 
 	// If VM is ready, but not yet started run reconcile
 	if cond != nil {
-		if (cond.Reason != nil && *cond.Reason == string(v2vv1.VirtualMachineReady)) && (instance.Spec.StartVM != nil && *instance.Spec.StartVM) {
+		if (cond.Reason != nil && *cond.Reason == string(v2vv1.VirtualMachineReady)) && shouldStartVM(instance) {
 			return true
 		}
 	}
@@ -1047,11 +1047,7 @@ func shouldReconcile(instance *v2vv1.VirtualMachineImport) bool {
 }
 
 func shouldStartVM(instance *v2vv1.VirtualMachineImport) bool {
-	return conditions.HasSucceededConditionOfReason(instance.Status.Conditions, v2vv1.VirtualMachineReady) &&
-		((instance.Spec.StartVM != nil && *instance.Spec.StartVM) ||
-			(instance.Spec.StartVM == nil &&
-				instance.Spec.Warm &&
-				instance.Annotations[sourceVMInitialState] == string(provider.VMStatusUp)))
+	return (instance.Spec.StartVM != nil && *instance.Spec.StartVM) || (instance.Spec.StartVM == nil && instance.Spec.Warm && instance.Annotations[sourceVMInitialState] == string(provider.VMStatusUp))
 }
 
 func shouldConvertGuest(provider provider.Provider, instance *v2vv1.VirtualMachineImport) bool {
